clear all

% Costanti fisiche
global g = 9.81;
% Dati sul carico a monte
global z1 = 15;
global z2 = 0;
global p1 = 0;
global p2 = 1e5;
% Dati sul fluido
global rho = 1e3;
global mu = 1e-3;
% Dati sulla condotta
global D = 0.15;
global L = 100;
global es = 0.001;
global k_A = 0.5;
global k_B = 0.5;

function z = target_function(Q)
	global g;
	global z1;
	global z2;
	global p1;
	global p2;
	global rho;
	global mu;
	global D;
	global L;
	global es;
	global k_A;
	global k_B;

	% Calcolo la velocità
	v = hspeed(Q, D);

	% Calcolo della differenza di carico totale
	H12_p = (p1 - p2)./(rho .* g);
	H12_z = z1 - z2;
	H12_v = (0 - v.^2) ./ (2 .* g);
	H12 = H12_p + H12_z + H12_v;

	% Calcolo la viscosità cinematica
	nu = mu ./ rho;
	% Calcolo il numero di Reynolds
	Re = Reynolds(v, D, nu);
	% Calcolo il coefficiente di attrito
	f = churchill(Re, es ./ D);

	% Calcolo le perdite di carico distribuite
	W_D = loss_l(f, D, L, v, g);

	% Calcolo le perdite di carico concentrate
	W_imbocco = loss_k(k_A, v, g);
	W_gomito = loss_k(k_B, v, g);
	W_C = W_imbocco + W_gomito;

	% Calcolo il valore della funzione
	z = H12 - W_D - W_C;
end

% target_function(0.04)

% Traccio la funzione
x = linspace(0, 0.05, 200);
plot(x, target_function(x));
grid()

% Soluzione usando il metodo di Octave
[X, FVAL, INFO] = fsolve(@target_function, 0.03);
X, FVAL, INFO