clear all

% Costanti fisiche
global g = 9.81;
% Dati sul carico a monte
global z1 = 10;
global z2 = 1;
global p1 = 0;
global p2 = 0;
% Dati sul fluido
global rho = 1e3;
global mu = 1e-3;
% Dati sulla condotta
global LA = 40;
global DA = 5e-2;
global LB = 10;
global DB = 10e-2;
global k_A = 0.5;
global k_B = 0.5;
global k_C = 1;
global Q = 4e-3;

function z = target_function(es)
	global g;
	global z1;
	global z2;
	global p1;
	global p2;
	global rho;
	global mu;
	global LA;
	global DA;
	global LB;
	global DB;
	global k_A;
	global k_B;
	global k_C;
	global Q;

	% Calcolo della differenza di carico totale
	H12_p = (p1 - p2)./(rho .* g);
	H12_z = z1 - z2;
	H12_v = (0 - 0) ./ (2 .* g);
	H12 = H12_p + H12_z + H12_v;

	% Calcolo la viscosità cinematica
	nu = mu ./ rho;

	% PRIMA TRATTA
	% Perdite distribuite
	vA = hspeed(Q, DA);
	ReA = Reynolds(vA, DA, nu);
	fA = churchill(ReA, es ./ DA);
	W_DA = loss_l(fA, DA, LA, vA, g);
	% Perdite concentrate (imbocco + gomito)
	W_CA = loss_k(k_A, vA, g) + loss_k(k_B, vA, g);
	W_A = W_DA + W_CA;

	% SECONDA TRATTA
	% Perdite distribuite
	vB = hspeed(Q, DB);
	ReB = Reynolds(vB, DB, nu);
	fB = churchill(ReB, es ./ DB);
	W_DB = loss_l(fB, DB, LB, vB, g);
	% Perdite concentrate (allargamento + sbocco)
	W_CB = (vA.^2 - vB.^2)./(2.*g) + loss_k(k_C, vB, DB);
	% Totale perdite di carico
	W_B = W_DB + W_CB;

	% Calcolo il valore della funzione
	z = H12 - W_A - W_B;
end

% target_function(0.0005)

% Traccio la funzione
x = linspace(0, 0.005, 200);
plot(x, target_function(x));
grid()

% Soluzione usando il metodo di Octave
[X, FVAL, INFO] = fsolve(@target_function, 0.001);
X, FVAL, INFO